%script to run multiple models in a batch. uses raymodel1.m
%running this script will generate the simulation model outputs presented
%in Rolland-Lagan et al. (2012) Development 139: 1188-1197.
% (c) Anne-Galle Rolland-Lagan, University of Ottawa, 2011

%clear all;% clears workspace variables if any
close all;% closes figures if any

opt=input('Press 1 to generate movie and record data, Press 2 to generate figures and record data');

pn0=uigetdir(pwd,'folder where to store default single model results');
cd(pn0);
pn1=uigetdir(pwd,'folder where to store ''mutant'' single model results');
cd(pn1);
pn2=uigetdir(pwd,'folder where to store default whole fin model results');
cd(pn2);

% parameters used in raymodel1 (in order): 
% number of simulation steps,alpha x0,beta,alphaG,Dx,Ds,alphah,output option,pn1,name of output file,
% simulation step at which amputation occurs (use -1 if not amputation), compartment at which ampuation occurs
%(use 0 if not amputation))

%single ray model - default parameters - non amputated, amputated at compartment 15 and regenerated to preamputation length, 
%amputated at compartment 30 and regenerated to preamputation length:
raymodel1(50000,5,0.005,1,0.9,0.1,0.3,2,opt,pn0,'wt_nocut',-1,0);
raymodel1(100000,5,0.005,1,0.9,0.1,0.3,2,opt,pn0,'wt_cut15',50000,15);
raymodel1(100000,5,0.005,1,0.9,0.1,0.3,2,opt,pn0,'wt_cut30',50000,30);
 
%single ray model - virtual mutants (non amputated):
raymodel1(50000,2.5,0.0025,1,0.9,0.1,0.3,2,opt,pn1,'mxp1',-1,0);
raymodel1(50000,10,0.01,1,0.9,0.1,0.3,2,opt,pn1,'mxp2',-1,0);

raymodel1(50000,5,0.005,1,0.45,0.1,0.3,2,opt,pn1,'mxt1',-1,0);
raymodel1(50000,5,0.005,1,1.8,0.1,0.3,2,opt,pn1,'mxt2',-1,0);

raymodel1(50000,5,0.005,0.6,0.9,0.1,0.3,2,opt,pn1,'mgp1',-1,0);
raymodel1(50000,5,0.005,3,0.9,0.1,0.3,2,opt,pn1,'mgp2',-1,0);

raymodel1(50000,5,0.005,1,0.9,0.05,0.3,2,opt,pn1,'mgt1',-1,0);
raymodel1(50000,5,0.005,1,0.9,0.2,0.3,2,opt,pn1,'mgt2',-1,0);

raymodel1(50000,5,0.005,1,0.9,0.1,0.3,1,opt,pn1,'mspj1',-1,0);
raymodel1(50000,5,0.005,1,0.9,0.1,0.3,4,opt,pn1,'mspj2',-1,0);

raymodel1(50000,5,0.005,1,0.9,0.1,0.15,2,opt,pn1,'mst1',-1,0);
raymodel1(50000,5,0.005,1,0.9,0.1,0.6,2,opt,pn1,'mst2',-1,0);

%whole fin model - default (amputated at compartment 15 and regenerated to preamputation length):
prodX0mat=[5 6 7 6 5 4 3 2 1 1 2 3 4 5 6 7 6 5]';
beta=prodX0mat*0.001; 
raymodel1(100000,prodX0mat,beta,1,0.9,0.1,0.3,2,opt,pn2,'wt_18rays_cut15',50000,15);

%virtual mutants with strong parameter changes:
raymodel1(50000,0.05,0.00005,1,0.9,0.1,0.3,2,opt,pn1,'mxp1b',-1,0);
raymodel1(50000,5,0.005,1,5,0.1,0.3,2,opt,pn1,'mxt2b',-1,0); 