function singleraymodel_dataanalysis(nm,opt)
% This function is used to analyze model output, and compare output from different models, for
% results presented in Rolland-Lagan et al. (2012) Development 139: 1188-1197.
% It generates .eps figures as well as an excel file of segment lengths (excel file output: 1 row per segment, column 1: model number, 
% column 2: position of segment, column 3: length of segment, column 4:
% segment number). Excel data file was then used to generate manuscript Figures 4E,4G and 5C in SPSS19 (IBM corporation,
% Somers, NY).
%
% input parameters:
% nm: number of models to compare
% opt: option to compare development or regeneration models. opt=0: for
% development, opt=1: for regeneration, opt=2 to compare wt and regenerated fins.
%
% user is prompted to select folder to store output figues and excel file,
% and to give name to the output excel file.
% user is also prompted to select model data files generated by raymodel1
% program (load each model .mat file one after the other - write down order in which models are loaded for 
% proper graph annotation, for instance if 3 models are compared, the output excel file will give model numbers 1,2 and 3,
% so user is responsible for knowing which model corresponds to which
% number).
% 
% after the program has run, all figures generated and excel file of
% segment lengths are in the output folder.
%
% e.g. singleraymodel_datanalaysis(2,1) can be used to compare models
% wt_cut15 and wt_cut30.
% singleraymodel_dataanalysis(13,0)can be used to compare wt and mutants
% singleraymodel_dataanalysis(3,2) can be used to compare wt and
% regenerated wt_cut15 and wt_cut30.
% (c) Anne-Galle Rolland-Lagan, University of Ottawa, 2011 

close all; 
if opt==1 || opt==2,
    timecut=input('time step at which amputation occurs - 50000 for manuscript');
    dt=input('dt value in models - 0.01 for manuscript');
    timecut=timecut*dt;%this is the time at which cut happens in the models to be compared
end

pn1=uigetdir(pwd,'folder where to store eps figures generated and excel file of segment lengths');
cd(pn1);
[fn1,pn1] = uiputfile('excel file to save segment lengths');
fn1=fullfile(pn1,fn1);

nfigs=0;
%preparing output figures
if opt<2
finL=figure;
set(finL,'Name','ray length as function of time');
segnum=figure;
set(segnum,'Name','segment number as function of time');
Xrecfig1=figure;
set(Xrecfig1,'Name','X level in first compartment');
Grecfig1=figure;
set(Grecfig1,'Name','G level in first compartment');
Xrecfig2=figure;
set(Xrecfig2,'Name','X level in last compartment');
Grecfig2=figure;
set(Grecfig2,'Name','G level in last compartment');

Srecfig1=figure;
set(Srecfig1,'Name','S level in first compartment');
Srecfig2=figure;
set(Srecfig2,'Name','S level in last compartment');
nfigs=nfigs+8;
end


if opt==0
Comp_finallength=figure;
set(Comp_finallength,'Name','comparison of ray lengths from different models at end of development simulations');
Comp_finalsegnum=figure;
set(Comp_finalsegnum,'Name','comparison of segment numbes from different models at end of development simulations');
nfigs=nfigs+2;
end

if opt==1

Regenerate1=figure;
set(Regenerate1,'Name','comparison of regenerate length');
nfigs=nfigs+1;
end;
colmap=lines(10);
avsegL=figure;
set(avsegL,'Name','average segment length');
nfigs=nfigs+1;


ct=0;
segL1=[];
for i=1:nm
    ct=ct+1;
    if ct==11
        ct=1;
    end
    col=colmap(ct,:);
    [fna pna]=uigetfile(pwd,'load model data');
    load([pna '\' fna]);
    cd(pna);


    if opt<2
    figure(finL);
    hold on,
    h1=line(curveL(:,1),curveL(:,2));
    set(h1,'Color',col);
    end
    
    segnum_tmp=1:size(segL,1)-1;
    
    segL2=ones(size(segL,1)-1,1)*i;
    segL2=cat(2,segL2,segL(2:size(segL,1),:),segnum_tmp');
    segL1=cat(1,segL1,segL2);
    
    if opt==1
        indx=max(find(curveL(:,1)<=timecut));
        figure(Regenerate1);
        hold on,
        lencut=curveL(indx+1,2);
        indx=min(find(curveL(:,1)>timecut));
        h1=line(curveL(indx:length(curveL),1),curveL(indx:length(curveL),2)-lencut);
        set(h1,'Color',col);
    end
    
    if opt<2
    figure(segnum);
    h3=line(curvesegnum(:,1),curvesegnum(:,2)-1);
    set(h3,'Color',col);
    
    figure(Xrecfig1);
    h3a=line(Xrec(:,1),Xrec(:,2));
    set(h3a,'Color',col);
    
    figure(Grecfig1);
    h3c=line(Grec(:,1),Grec(:,2));
    set(h3c,'Color',col);
    
     figure(Xrecfig2);
    h3b=line(Xrec(:,1),Xrec(:,3));
    set(h3b,'Color',col);
    
    figure(Grecfig2);
    h3d=line(Grec(:,1),Grec(:,3));
    set(h3d,'Color',col);
    
    figure(Srecfig1);
    h3e=line(Srec(:,1),Srec(:,2));
    set(h3e,'Color',col);
    
    figure(Srecfig2);
    h3f=line(Srec(:,1),Srec(:,3));
    set(h3f,'Color',col);
    end
    
    figure(avsegL);
    hold on,
    h4=bar(i,mean(segL(2:size(segL,1),2)));
    
    if opt==0
    figure(Comp_finallength);
    hold on,
    h5=bar(i,max(curveL(:,2)));
    
    figure(Comp_finalsegnum);
    hold on,
    h5=bar(i,max(segnum_tmp));
    end
    
end;


cd(pn1);


for i=1:nfigs
    set(gcf, 'PaperPositionMode', 'manual');
    set(gcf, 'PaperUnits', 'centimeters');
    set(gcf, 'PaperPosition', [2 1 7 5]);
    print ('-depsc2', get(gcf,'Name'));
    close gcf;
end


%make excel file
xlswrite(fn1,segL1); 
